import {
  AppDatabase, ICell, IJson, IText,
} from "./data";

export class WriterJson {
  static mockJson(count: number): IJson {
    let mock: IJson = { j: [] };
    for (let i = 0; i < count; i++) {
      mock.j.push({
        p: {}, s: 0, v: '', m: '', f: '', fm: {}, h: '', n: '',
      });
    }
    return mock;
  }

  static async writeJson(json: IJson): Promise<void> {
    const database = new AppDatabase();
    await database.jsons.add(json);
  }

  static async write1w(): Promise<void> {
    const mockJson = WriterJson.mockJson(10000);
    console.time("写入1W数据耗时: ");
    await WriterJson.writeJson(mockJson);
    console.timeEnd("写入1W数据耗时: ");
  }

  static async write5w(): Promise<void> {
    const mockJson = WriterJson.mockJson(50000);
    console.time("写入5W数据耗时: ");
    await WriterJson.writeJson(mockJson);
    console.timeEnd("写入5W数据耗时: ");
  }

  static async write10w(): Promise<void> {
    const mockJson = WriterJson.mockJson(100000);
    console.time("写入10W数据耗时: ");
    await WriterJson.writeJson(mockJson);
    console.timeEnd("写入10W数据耗时: ");
  }

  static async write50w(): Promise<void> {
    const mockJson = WriterJson.mockJson(500000);
    console.time("写入50W数据耗时: ");
    await WriterJson.writeJson(mockJson);
    console.timeEnd("写入50W数据耗时: ");
  }

  static async write100w(): Promise<void> {
    const mockJson = WriterJson.mockJson(1000000);
    console.time("写入100W数据耗时: ");
    await WriterJson.writeJson(mockJson);
    console.timeEnd("写入100W数据耗时: ");
  }

  static async write500w(): Promise<void> {
    const mockJson = WriterJson.mockJson(5000000);
    console.time("写入500W数据耗时: ");
    await WriterJson.writeJson(mockJson);
    console.timeEnd("写入500W数据耗时: ");
  }

  static async write1000w(): Promise<void> {
    const mockJson = WriterJson.mockJson(10000000);
    console.time("写入1000W数据耗时: ");
    await WriterJson.writeJson(mockJson);
    console.timeEnd("写入1000W数据耗时: ");
  }
}

export class WriterJsonText {
  static mockJsonText(count: number): IText {
    let mock: ICell[] = [];
    for (let i = 0; i < count; i++) {
      mock.push({
        p: {}, s: 0, v: '', m: '', f: '', fm: {}, h: '', n: '',
      });
    }
    return {
      t: JSON.stringify(mock),
    };
  }

  static async writeJsonText(text: IText): Promise<void> {
    const database = new AppDatabase();
    await database.text.add(text);
  }

  static async write1w(): Promise<void> {
    const mockJsonText = WriterJsonText.mockJsonText(10000);
    console.time("写入1W数据耗时: ");
    await WriterJsonText.writeJsonText(mockJsonText);
    console.timeEnd("写入1W数据耗时: ");
  }

  static async write5w(): Promise<void> {
    const mockJsonText = WriterJsonText.mockJsonText(50000);
    console.time("写入5W数据耗时: ");
    await WriterJsonText.writeJsonText(mockJsonText);
    console.timeEnd("写入5W数据耗时: ");
  }

  static async write10w(): Promise<void> {
    const mockJsonText = WriterJsonText.mockJsonText(100000);
    console.time("写入10W数据耗时: ");
    await WriterJsonText.writeJsonText(mockJsonText);
    console.timeEnd("写入10W数据耗时: ");
  }

  static async write50w(): Promise<void> {
    const mockJsonText = WriterJsonText.mockJsonText(500000);
    console.time("写入50W数据耗时: ");
    await WriterJsonText.writeJsonText(mockJsonText);
    console.timeEnd("写入50W数据耗时: ");
  }

  static async write100w(): Promise<void> {
    const mockJsonText = WriterJsonText.mockJsonText(1000000);
    console.time("写入100W数据耗时: ");
    await WriterJsonText.writeJsonText(mockJsonText);
    console.timeEnd("写入100W数据耗时: ");
  }

  static async write500w(): Promise<void> {
    const mockJsonText = WriterJsonText.mockJsonText(5000000);
    console.time("写入500W数据耗时: ");
    await WriterJsonText.writeJsonText(mockJsonText);
    console.timeEnd("写入500W数据耗时: ");
  }

  static async write1000w(): Promise<void> {
    const mockJsonText = WriterJsonText.mockJsonText(10000000);
    console.time("写入1000W数据耗时: ");
    await WriterJsonText.writeJsonText(mockJsonText);
    console.timeEnd("写入1000W数据耗时: ");
  }
}

export class WriterArray {
  static mockArray(count: number): ICell[] {
    let cells = [];
    for (let i = 0; i < count; i++) {
      cells.push({
        p: {}, s: 0, v: '', m: '', f: '', fm: {}, h: '', n: '',
      });
    }
    return cells;
  }

  static async writeArray(cells: ICell[]): Promise<void> {
    let database = new AppDatabase();
    for (let i = 0; i < cells.length; i++) {
      let cell = cells[i];
      await database.cells.add(cell);
    }
  }

  static async write1w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(10000);
    console.time("写入1W数据耗时: ");
    await WriterArray.writeArray(mockArray);
    console.timeEnd("写入1W数据耗时: ");
  }

  static async write5w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(50000);
    console.time("写入5W数据耗时: ");
    await WriterArray.writeArray(mockArray);
    console.timeEnd("写入5W数据耗时: ");
  }

  static async write10w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(100000);
    console.time("写入10W数据耗时: ");
    await WriterArray.writeArray(mockArray);
    console.timeEnd("写入10W数据耗时: ");
  }

  static async write50w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(500000);
    console.time("写入50W数据耗时: ");
    await WriterArray.writeArray(mockArray);
    console.timeEnd("写入50W数据耗时: ");
  }

  static async write100w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(1000000);
    console.time("写入100W数据耗时: ");
    await WriterArray.writeArray(mockArray);
    console.timeEnd("写入100W数据耗时: ");
  }

  static async write500w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(5000000);
    console.time("写入500W数据耗时: ");
    await WriterArray.writeArray(mockArray);
    console.timeEnd("写入500W数据耗时: ");
  }

  static async write1000w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(10000000);
    console.time("写入1000W数据耗时: ");
    await WriterArray.writeArray(mockArray);
    console.timeEnd("写入1000W数据耗时: ");
  }
}

export class WriterBulkArray {
  static mockArray(count: number): ICell[] {
    let cells = [];
    for (let i = 0; i < count; i++) {
      cells.push({
        p: {}, s: 0, v: '', m: '', f: '', fm: {}, h: '', n: '',
      });
    }
    return cells;
  }

  static async writeBulkArray(cells: ICell[]): Promise<void> {
    const database = new AppDatabase();
    await database.cells.bulkAdd(cells);
  }

  static async write1w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(10000);
    console.time("写入1W数据耗时: ");
    await WriterBulkArray.writeBulkArray(mockArray);
    console.timeEnd("写入1W数据耗时: ");
  }

  static async write5w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(50000);
    console.time("写入5W数据耗时: ");
    await WriterBulkArray.writeBulkArray(mockArray);
    console.timeEnd("写入5W数据耗时: ");
  }

  static async write10w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(100000);
    console.time("写入10W数据耗时: ");
    await WriterBulkArray.writeBulkArray(mockArray);
    console.timeEnd("写入10W数据耗时: ");
  }

  static async write50w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(500000);
    console.time("写入50W数据耗时: ");
    await WriterBulkArray.writeBulkArray(mockArray);
    console.timeEnd("写入50W数据耗时: ");
  }

  static async write100w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(1000000);
    console.time("写入100W数据耗时: ");
    await WriterBulkArray.writeBulkArray(mockArray);
    console.timeEnd("写入100W数据耗时: ");
  }

  static async write500w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(5000000);
    console.time("写入500W数据耗时: ");
    await WriterBulkArray.writeBulkArray(mockArray);
    console.timeEnd("写入500W数据耗时: ");
  }

  static async write1000w(): Promise<void> {
    const mockArray = WriterBulkArray.mockArray(10000000);
    console.time("写入1000W数据耗时: ");
    await WriterBulkArray.writeBulkArray(mockArray);
    console.timeEnd("写入1000W数据耗时: ");
  }
}
